@@ -73,6 +73,7 @@ from xml.etree.ElementTree import fromstring
 
 import click
 from dandischema import models
+from dandischema.digests.dandietag import DandiETag
 from pydantic import BaseModel, Field, PrivateAttr
 import requests
 import tenacity
@@ -83,10 +84,10 @@ from .consts import (
     MAX_CHUNK_SIZE,
     RETRY_STATUSES,
     DandiInstance,
+    EmbargoStatus,
     known_instances,
     known_instances_rev,
 )
-from .core.digests.dandietag import DandiETag
 from .exceptions import NotFoundError, SchemaVersionError
 from .keyring import keyring_lookup
 from .utils import USER_AGENT, check_dandi_version, ensure_datetime, is_interactive
@@ -682,6 +683,11 @@ class RemoteDandiset:
         """The name of the registered contact person for the Dandiset"""
         return self._get_data()["contact_person"]
 
+    @property
+    def embargo_status(self) -> EmbargoStatus:
+        """The current embargo status for the Dandiset"""
+        return EmbargoStatus(self._get_data()["embargo_status"])
+
     @property
     def most_recent_published_version(self) -> Optional[Version]:
         """
@@ -702,20 +708,36 @@ class RemoteDandiset:
     @property
     def api_path(self) -> str:
         """
-        The API path (relative to the base endpoint for a Dandi Archive API) at
-        which requests for interacting with the Dandiset itself are made
+        The path (relative to the base endpoint for a Dandi Archive API) at
+        which API requests for interacting with the Dandiset itself are made
         """
         return f"/dandisets/{self.identifier}/"
 
+    @property
+    def api_url(self) -> str:
+        """
+        The URL at which API requests for interacting with the Dandiset itself
+        are made
+        """
+        return self.client.get_url(self.api_path)
+
     @property
     def version_api_path(self) -> str:
         """
-        The API path (relative to the base endpoint for a Dandi Archive API) at
-        which requests for interacting with the version in question of the
+        The path (relative to the base endpoint for a Dandi Archive API) at
+        which API requests for interacting with the version in question of the
         Dandiset are made
         """
         return f"/dandisets/{self.identifier}/versions/{self.version_id}/"
 
+    @property
+    def version_api_url(self) -> str:
+        """
+        The URL at which API requests for interacting with the version in
+        question of the Dandiset are made
+        """
+        return self.client.get_url(self.version_api_path)
+
     @classmethod
     def from_data(
         cls, client: "DandiAPIClient", data: Dict[str, Any]
@@ -1237,11 +1259,19 @@ class BaseRemoteAsset(APIBase):
     @property
     def api_path(self) -> str:
         """
-        The API path (relative to the base endpoint for a Dandi Archive API) at
-        which requests for interacting with the asset itself are made
+        The path (relative to the base endpoint for a Dandi Archive API) at
+        which API requests for interacting with the asset itself are made
         """
         return f"/assets/{self.identifier}/"
 
+    @property
+    def api_url(self) -> str:
+        """
+        The URL at which API requests for interacting with the asset itself are
+        made
+        """
+        return self.client.get_url(self.api_path)
+
     @property
     def base_download_url(self) -> str:
         """
@@ -1417,11 +1447,19 @@ class RemoteAsset(BaseRemoteAsset):
     @property
     def api_path(self) -> str:
         """
-        The API path (relative to the base endpoint for a Dandi Archive API) at
-        which requests for interacting with the asset itself are made
+        The path (relative to the base endpoint for a Dandi Archive API) at
+        which API requests for interacting with the asset itself are made
         """
         return f"/dandisets/{self.dandiset_id}/versions/{self.version_id}/assets/{self.identifier}/"
 
+    @property
+    def api_url(self) -> str:
+        """
+        The URL at which API requests for interacting with the asset itself are
+        made
+        """
+        return self.client.get_url(self.api_path)
+
     @property
     def download_url(self) -> str:
         """
